==> mediawiki-1.15.5p0.tgz: mediawiki/languages/messages/MessagesChr.php <==
<?php
/** Cherokee (ᏣᎳᎩ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Maximillion Pegasus
 */

$messages = array(
# Dates
'january'  => 'UᏃᎸᏔᏂ',
'february' => 'KᎠᎦᎵ',
'march'    => 'ᎠᏄᏱ',
'april'    => 'ᏥᎶᏂ',
'june'     => 'DᎡᎭᎷᏱ',

'about'          => 'ᎬᏩᏚᏫᏛ',
'article'        => 'ᎤᏓᏡᎬ',
'qbpageinfo'     => 'ᎦᎷᎯᏍᏗ',
'qbspecialpages' => 'ᎤᏤᎵᏛ',
'navigation'     => 'ᎠᏂᎩᏍᏗ ᏥᏳ',

'help'             => 'ᎠᎵᏍᏕᎸᏗ',
'search'           => 'ᎠᏯᏍᏗ',
'go'               => 'ᎮᎦ',
'history'          => 'ᏆᏥ ᎧᏃᎮᏍᎩ',
'history_short'    => 'ᎧᏃᎮᏍᎩ',
'printableversion' => 'ᎦᎴᏯᏛ ᏅᎬᎪᏔᏅᎯ',
'permalink'        => 'ᏂᎪᎯᎸ ᏕᎬᏔᏛ',
'talkpagelinktext' => 'ᎧᏃᎮᎸᏗ',
'talk'             => 'ᎧᏃᎮᎸᏗ',
'toolbox'          => 'ᎪᎱᏍᏗ ᎬᏔᏂᏓᏍᏗ ᎧᏁᏌᎢ',
'otherlanguages'   => 'ᎭᏫᎾᏗᏢ ᏐᎢ ᏗᎦᏬᏂᎯᏍᏗ',
'jumptosearch'     => 'ᎡᏗt',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutpage'            => 'Project:ᎬᏩᏚᏫᏛ',
'currentevents'        => 'ᏗᏤᎢ',
'mainpage'             => 'ᎤᎵᎮᎵᏍᏗ',
'mainpage-description' => 'ᎤᎵᎮᎵᏍᏗ',
'portal'               => 'ᎾᎥ ᏄᎾᏓᎸ ᎠᏍᏚᎢᏍᏗ',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'ᎤᏓᏡᎬ',
'nstab-category' => 'ᏗᎦᎪᏗ',

# General errors
'viewsource' => 'DᎢᎧᏃᏗᎢ DᎢᏓᎴᎲᏍᎬ',

# Diffs
'editundo' => 'IᎬᎾᏕᏍᏗ',

# Search results
'powersearch' => 'ᎠᏯᏍᏗ',

# Preferences page
'searchresultshead' => 'ᎠᏯᏍᏗ',

# Recent changes
'recentchanges' => 'ᎾᏞᎬ ᏗᎦᏁᏟᏴᏍᏗ',

# Recent changes linked
'recentchangeslinked' => 'ᎪᎱᏍᏗ ᎠᎾᏓᏛᏂ ᏗᎦᏁᏟᏴᏍᏗ',

# Upload
'upload' => 'ᎦᎸᎳᏗᏢ ᎠᎧᎵᎢ ᎠᏝᎥᎢ',

# Random page
'randompage' => 'ᎤᏍᏆᏂᎪᏗ ᎤᏆᏓᏛ',

# Watchlist
'watch' => 'WᎠᏥ',

# Delete
'actioncomplete' => 'ᎠᏍᏆᏙᏅᎯ',

# What links here
'whatlinkshere' => 'ᎦᏙ ᎤᏍᏗ ᏗᏕᎬᏔᏛ ᎠᎭᏂ',

# Block/unblock
'proxyblocksuccess' => 'ᎠᏍᏆᏛᎯ.',

# Special:NewFiles
'ilsubmit' => 'ᎠᏯᏍᏗ',

# Special:SpecialPages
'specialpages' => 'ᎤᏤᎵᏛ ᏚᏆᏓᏛ',

);

==> mediawiki-1.19.1.tgz: mediawiki/languages/messages/MessagesChr.php <==
<?php
/** Cherokee (ᏣᎳᎩ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Etse (on chr.wikipedia.org)
 * @author Gmaxwell (on chr.wikipedia.org)
 * @author Maximillion Pegasus
 * @author Srtxg (on chr.wikipedia.org)
 */

$messages = array(
# Dates
'january'  => 'UᏃᎸᏔᏂ',
'february' => 'KᎠᎦᎵ',
'march'    => 'ᎠᏄᏱ',
'april'    => 'ᏥᎶᏂ',
'june'     => 'DᎡᎭᎷᏱ',

'about'      => 'ᎬᏩᏚᏫᏛ',
'article'    => 'ᎤᏓᏡᎬ',
'navigation' => 'ᎠᏂᎩᏍᏗ ᏥᏳ',

# Cologne Blue skin
'qbpageinfo'     => 'ᎦᎷᎯᏍᏗ',
'qbspecialpages' => 'ᎤᏤᎵᏛ',

'help'             => 'ᎠᎵᏍᏕᎸᏗ',
'search'           => 'ᎠᏯᏍᏗ',
'go'               => 'ᎮᎦ',
'history'          => 'ᏆᏥ ᎧᏃᎮᏍᎩ',
'history_short'    => 'ᎧᏃᎮᏍᎩ',
'printableversion' => 'ᎦᎴᏯᏛ ᏅᎬᎪᏔᏅᎯ',
'permalink'        => 'ᏂᎪᎯᎸ ᏕᎬᏔᏛ',
'talkpagelinktext' => 'ᎧᏃᎮᎸᏗ',
'talk'             => 'ᎧᏃᎮᎸᏗ',
'toolbox'          => 'ᎪᎱᏍᏗ ᎬᏔᏂᏓᏍᏗ ᎧᏁᏌᎢ',
'otherlanguages'   => 'ᎭᏫᎾᏗᏢ ᏐᎢ ᏗᎦᏬᏂᎯᏍᏗ',
'jumptosearch'     => 'ᎡᏗt',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutpage'            => 'Project:ᎬᏩᏚᏫᏛ',
'currentevents'        => 'ᏗᏤᎢ',
'mainpage'             => 'ᎤᎵᎮᎵᏍᏗ',
'mainpage-description' => 'ᎤᎵᎮᎵᏍᏗ',
'portal'               => 'ᎾᎥ ᏄᎾᏓᎸ ᎠᏍᏚᎢᏍᏗ',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'ᎤᏓᏡᎬ',
'nstab-category' => 'ᏗᎦᎪᏗ',

# General errors
'viewsource' => 'DᎢᎧᏃᏗᎢ DᎢᏓᎴᎲᏍᎬ',

# Diffs
'editundo' => 'IᎬᎾᏕᏍᏗ',

# Search results
'powersearch' => 'ᎠᏯᏍᏗ',

# Preferences page
'searchresultshead' => 'ᎠᏯᏍᏗ',

# Recent changes
'recentchanges' => 'ᎾᏞᎬ ᏗᎦᏁᏟᏴᏍᏗ',

# Recent changes linked
'recentchangeslinked'         => 'ᎪᎱᏍᏗ ᎠᎾᏓᏛᏂ ᏗᎦᏁᏟᏴᏍᏗ',
'recentchangeslinked-feed'    => 'ᎪᎱᏍᏗ ᎠᎾᏓᏛᏂ ᏗᎦᏁᏟᏴᏍᏗ',
'recentchangeslinked-toolbox' => 'ᎪᎱᏍᏗ ᎠᎾᏓᏛᏂ ᏗᎦᏁᏟᏴᏍᏗ',

# Upload
'upload' => 'ᎦᎸᎳᏗᏢ ᎠᎧᎵᎢ ᎠᏝᎥᎢ',

# Random page
'randompage' => 'ᎤᏍᏆᏂᎪᏗ ᎤᏆᏓᏛ',

# Watchlist
'watch' => 'WᎠᏥ',

# Delete
'actioncomplete' => 'ᎠᏍᏆᏙᏅᎯ',

'sp-contributions-talk' => 'ᎧᏃᎮᎸᏗ',

# What links here
'whatlinkshere' => 'ᎦᏙ ᎤᏍᏗ ᏗᏕᎬᏔᏛ ᎠᎭᏂ',

# Block/unblock
'proxyblocksuccess' => 'ᎠᏍᏆᏛᎯ.',

# Special:NewFiles
'ilsubmit' => 'ᎠᏯᏍᏗ',

# Special:SpecialPages
'specialpages' => 'ᎤᏤᎵᏛ ᏚᏆᏓᏛ',

);
